@@ -1,6 +1,6 @@
 import importlib
 import re
-from datetime import datetime, date
+from datetime import date, datetime
 from enum import Enum
 
 from semver import VersionInfo
@@ -71,7 +71,7 @@ Arguments: Dict object; the module which contains the class, the parsed object i
                 raise ClassNotFoundError(
                     "Class '%s' not found in the given module!" % t
                 )
-            except TypeError as te:
+            except TypeError:
                 raise TypeError(
                     "Make sure there is an constuctor that doesn't take any arguments (class: %s)"
                     % t
